aboutsummaryrefslogtreecommitdiff
path: root/build2/utility.hxx
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2018-07-26 14:12:56 +0300
committerKaren Arutyunov <karen@codesynthesis.com>2018-07-30 13:04:37 +0300
commitd90ac405ae50f84a3cf4ba0b806cca1c89f81cff (patch)
tree3f66be39a80a0a32cbba332e34b418fa1fc9ad02 /build2/utility.hxx
parente92a1aab0e1c7c9ba8e6ab9a7049207468ca53fc (diff)
Make project variable to be of project_name type
Diffstat (limited to 'build2/utility.hxx')
-rw-r--r--build2/utility.hxx16
1 files changed, 9 insertions, 7 deletions
diff --git a/build2/utility.hxx b/build2/utility.hxx
index 6e76f05..0beec2e 100644
--- a/build2/utility.hxx
+++ b/build2/utility.hxx
@@ -388,15 +388,17 @@ namespace build2
verbosity, pp, args, forward<F> (f), error, ignore_exit, checksum);
}
// Empty/nullopt string and path.
//
- extern const string empty_string;
- extern const path empty_path;
- extern const dir_path empty_dir_path;
+ extern const string empty_string;
+ extern const path empty_path;
+ extern const dir_path empty_dir_path;
+ extern const project_name empty_project_name;
- extern const optional<string> nullopt_string;
- extern const optional<path> nullopt_path;
- extern const optional<dir_path> nullopt_dir_path;
+ extern const optional<string> nullopt_string;
+ extern const optional<path> nullopt_path;
+ extern const optional<dir_path> nullopt_dir_path;
+ extern const optional<project_name> nullopt_project_name;
// Hash a path potentially without the specific directory prefix.
//
@@ -388,15 +388,17 @@ namespace build2
verbosity, pp, args, forward<F> (f), error, ignore_exit, checksum);
}
- // Empty/nullopt string and path.
+ // Empty/nullopt string, path, and project name.
//